import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/* eslint-disable no-console */
import React, { useContext, useRef, useState } from 'react';
import classnames from 'classnames';
import CollapseContext from './CollapseContext';
import { BORDER_TOP_BOTTOM } from '../utils/constant';
import { useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

function validateModelValue(modelValue, accordion) {
  if (accordion && Array.isArray(modelValue)) {
    console.error('[ReactVant] Collapse: "value" should not be Array in accordion mode');
    return false;
  }

  if (!accordion && !Array.isArray(modelValue)) {
    console.error('[rc-ui-lib] Collapse: "value" should be Array in non-accordion mode');
    return false;
  }

  return true;
}

var Collapse = function Collapse(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('collapse', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var innerEffect = useRef(false);

  var _useState = useState(function () {
    var _props$value;

    return (_props$value = props.value) !== null && _props$value !== void 0 ? _props$value : props.initExpanded;
  }),
      _useState2 = _slicedToArray(_useState, 2),
      expanded = _useState2[0],
      setExpanded = _useState2[1];

  var updateName = function updateName(name) {
    var _props$onChange;

    innerEffect.current = true;
    setExpanded(name);
    (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, name);
  };

  var toggle = function toggle(name, isExpanded) {
    var accordion = props.accordion;

    if (accordion) {
      if (name === expanded) {
        name = '';
      }
    } else if (isExpanded) {
      name = expanded.concat(name);
    } else {
      name = expanded.filter(function (activeName) {
        return activeName !== name;
      });
    }

    updateName(name);
  };

  var isExpanded = function isExpanded(name) {
    var accordion = props.accordion;

    if (process.env.NODE_ENV !== 'production' && !validateModelValue(expanded, accordion)) {
      return false;
    }

    return accordion ? expanded === name : expanded.includes(name);
  };

  useUpdateEffect(function () {
    if (innerEffect.current) {
      innerEffect.current = false;
      return;
    }

    setExpanded(props.value);
  }, [props.value]);
  return /*#__PURE__*/React.createElement(CollapseContext.Provider, {
    value: {
      isExpanded: isExpanded,
      toggle: toggle
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem(), _defineProperty({}, BORDER_TOP_BOTTOM, props.border))
  }, React.Children.toArray(props.children).filter(Boolean).map(function (child, index) {
    return /*#__PURE__*/React.cloneElement(child, {
      index: index
    });
  })));
};

Collapse.defaultProps = {
  border: true,
  initExpanded: []
};
export default Collapse;