import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
var _excluded = ["border", "disabled", "children", "readonly"];
import React, { useMemo, useRef, useContext, useState, forwardRef, useImperativeHandle } from 'react';
import classnames from 'classnames';
import Cell from '../cell';
import CollapseContext from './CollapseContext';
import useLazyRender from '../hooks/use-lazy-render';
import { raf, doubleRaf } from '../utils/raf';
import { useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var CollapseItem = /*#__PURE__*/forwardRef(function (props, ref) {
  var index = props.index;
  var parent = useContext(CollapseContext);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('collapse-item', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var wrapperRef = useRef(null);
  var contentRef = useRef(null);
  var name = useMemo(function () {
    var _props$name;

    return (_props$name = props.name) !== null && _props$name !== void 0 ? _props$name : index;
  }, [props.name]);
  var expanded = useMemo(function () {
    if (parent) {
      return parent.isExpanded(name);
    }

    return null;
  }, [parent, name]);

  var _useState = useState(function () {
    return expanded;
  }),
      _useState2 = _slicedToArray(_useState, 2),
      show = _useState2[0],
      setShow = _useState2[1];

  var lazyRender = useLazyRender(show);

  var onTransitionEnd = function onTransitionEnd() {
    if (!expanded) {
      setShow(false);
    } else {
      wrapperRef.current.style.height = '';
    }
  };

  useUpdateEffect(function () {
    if (expanded) {
      setShow(true);
    }

    raf(function () {
      if (!contentRef.current || !wrapperRef.current) {
        return;
      }

      var offsetHeight = contentRef.current.offsetHeight;

      if (offsetHeight) {
        var contentHeight = "".concat(offsetHeight, "px");
        wrapperRef.current.style.height = expanded ? 0 : contentHeight; // use double raf to ensure animation can start

        doubleRaf(function () {
          wrapperRef.current.style.height = expanded ? contentHeight : 0;
        });
      } else {
        onTransitionEnd();
      }
    });
  }, [expanded]);

  var toggle = function toggle() {
    var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : !expanded;
    parent.toggle(name, value);
  };

  var onClickTitle = function onClickTitle() {
    if (!props.disabled && !props.readonly) {
      toggle();
    }
  };

  var renderTitle = function renderTitle() {
    var border = props.border,
        disabled = props.disabled,
        children = props.children,
        readonly = props.readonly,
        others = _objectWithoutProperties(props, _excluded);

    return /*#__PURE__*/React.createElement(Cell, _extends({
      className: classnames(bem('title', {
        disabled: disabled,
        expanded: expanded,
        borderless: !border
      })),
      "aria-expanded": String(expanded),
      onClick: onClickTitle
    }, others, {
      isLink: readonly ? false : others.isLink,
      clickable: disabled || readonly ? false : others.clickable
    }));
  };

  var renderContent = lazyRender(function () {
    return /*#__PURE__*/React.createElement("div", {
      ref: wrapperRef,
      className: classnames(bem('wrapper')),
      onTransitionEnd: onTransitionEnd
    }, /*#__PURE__*/React.createElement("div", {
      ref: contentRef,
      className: classnames(bem('content'))
    }, props.children));
  });
  useImperativeHandle(ref, function () {
    return {
      toggle: toggle
    };
  });
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem({
      border: index && props.border
    }))
  }, renderTitle(), renderContent());
});
CollapseItem.defaultProps = {
  isLink: true,
  border: true
};
export default CollapseItem;