import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
var _excluded = ["children", "className", "autoplay"],
    _excluded2 = ["initialSwipe", "duration", "onChange", "vertical", "showIndicators"];
import React, { useRef, Children, cloneElement, forwardRef, useImperativeHandle, useContext } from 'react';
import cls from 'classnames';
import SwiperCore, { Pagination, Autoplay, Lazy } from 'swiper';
import { Swiper } from 'swiper/react';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
SwiperCore.use([Autoplay, Pagination, Lazy]);
var Swipe = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('swipe', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _parseOptions = parseOptions(props),
      children = _parseOptions.children,
      className = _parseOptions.className,
      autoplay = _parseOptions.autoplay,
      otherProps = _objectWithoutProperties(_parseOptions, _excluded);

  var internalSwipeRef = useRef(null);
  useImperativeHandle(ref, function () {
    return internalSwipeRef.current;
  }, [internalSwipeRef.current]);
  return /*#__PURE__*/React.createElement(Swiper, _extends({
    className: cls(className, bem()),
    onSwiper: function onSwiper(swiper) {
      internalSwipeRef.current = swiper;
    },
    autoplay: autoplay
  }, otherProps), Children.toArray(children).filter(Boolean).map(function (child) {
    return /*#__PURE__*/cloneElement(child, {
      className: 'rc-swipe-item'
    });
  }));
});
Swipe.defaultProps = {
  initialSwipe: 0,
  duration: 500,
  pagination: true
};

function parseOptions(opts) {
  var initialSwipe = opts.initialSwipe,
      duration = opts.duration,
      onChange = opts.onChange,
      vertical = opts.vertical,
      showIndicators = opts.showIndicators,
      rest = _objectWithoutProperties(opts, _excluded2);

  if (vertical) {
    rest.direction = 'vertical';
  }

  if (typeof showIndicators === 'boolean') {
    if (!showIndicators) rest.pagination = false;
  }

  rest.initialSlide = initialSwipe;
  rest.speed = duration;

  if (rest.autoplay && typeof rest.autoplay === 'number') {
    rest.autoplay = {
      delay: rest.autoplay,
      disableOnInteraction: false
    };
  }

  if (onChange) {
    rest.onSlideChange = function (sw) {
      var idx = opts.loop ? sw.realIndex : sw.activeIndex;
      onChange === null || onChange === void 0 ? void 0 : onChange(idx);
    };
  }

  return rest;
}

export default Swipe;