"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _defineProperty2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

  _defineProperty2 = function _defineProperty2() {
    return data;
  };

  return data;
}

function _slicedToArray2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

  _slicedToArray2 = function _slicedToArray2() {
    return data;
  };

  return data;
}

function _react() {
  var data = _interopRequireWildcard(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _classnames() {
  var data = _interopRequireDefault(require("classnames"));

  _classnames = function _classnames() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../icon"));

var _cell = _interopRequireDefault(require("../cell"));

var _utils = require("../utils");

var _ConfigProviderContext = _interopRequireDefault(require("../config-provider/ConfigProviderContext"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var ICON_SIZE = '16px';
var Field = /*#__PURE__*/(0, _react().forwardRef)(function (props, ref) {
  var _bem;

  var _useContext = (0, _react().useContext)(_ConfigProviderContext.default),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('field', prefixCls),
      _createNamespace2 = (0, _slicedToArray2().default)(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useState = (0, _react().useState)(false),
      _useState2 = (0, _slicedToArray2().default)(_useState, 2),
      inputFocus = _useState2[0],
      setInputFocus = _useState2[1];

  var fieldRef = (0, _react().useRef)(null);
  var inputRef = (0, _react().useRef)(null);
  (0, _react().useEffect)(function () {
    if (props.getFieldRef) props.getFieldRef(fieldRef);
    if (props.getInputRef) props.getInputRef(inputRef);
  }, [props.getFieldRef, props.getInputRef]);

  var focus = function focus() {
    if (inputRef.current) {
      inputRef.current.focus();
    }
  };

  var blur = function blur() {
    if (inputRef.current) {
      inputRef.current.blur();
    }
  };

  (0, _react().useImperativeHandle)(ref, function () {
    return {
      focus: focus,
      blur: blur
    };
  });

  var getProp = function getProp(key) {
    if ((0, _utils.isDef)(props[key])) {
      return props[key];
    }

    return null;
  };

  var getModelValue = function getModelValue() {
    var _props$value;

    return String((_props$value = props.value) !== null && _props$value !== void 0 ? _props$value : '');
  };

  var showClear = (0, _react().useMemo)(function () {
    var readonly = getProp('readonly');

    if (props.clearable && !readonly) {
      var hasValue = getModelValue() !== '';
      var trigger = props.clearTrigger === 'always' || props.clearTrigger === 'focus' && inputFocus;
      return hasValue && trigger;
    }

    return false;
  }, [props.value, props.clearTrigger, inputFocus]);

  var labelStyle = function labelStyle() {
    var labelW = getProp('labelWidth');

    if (labelW) {
      return {
        width: (0, _utils.addUnit)(labelW)
      };
    }

    return {};
  };

  var adjustSize = function adjustSize() {
    var input = inputRef.current;

    if (!(props.type === 'textarea' && props.autosize) || !input) {
      return;
    }

    input.style.height = 'auto';
    var height = input.scrollHeight;

    if ((0, _utils.isObject)(props.autosize)) {
      var _props$autosize = props.autosize,
          maxHeight = _props$autosize.maxHeight,
          minHeight = _props$autosize.minHeight;

      if (maxHeight) {
        height = Math.min(height, maxHeight);
      }

      if (minHeight) {
        height = Math.max(height, minHeight);
      }
    }

    if (height) {
      input.style.height = "".concat(height, "px");
    }
  };

  (0, _react().useEffect)(function () {
    adjustSize();
  }, [props.value]);

  var formatValue = function formatValue(inputValue) {
    var trigger = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'onChange';
    var formatTrigger = props.formatTrigger,
        formatter = props.formatter;

    if (formatter && trigger === formatTrigger) {
      return formatter(inputValue);
    }

    return inputValue;
  };

  var renderInput = function renderInput() {
    var type = props.type,
        error = props.error,
        name = props.name,
        rows = props.rows,
        value = props.value,
        placeholder = props.placeholder,
        disabled = props.disabled,
        readonly = props.readonly,
        onClickInput = props.onClickInput;
    var controlClass = bem('control', [getProp('inputAlign'), {
      error: error,
      custom: !!props.children,
      'min-height': props.type === 'textarea' && !props.autosize
    }]);

    if (props.children) {
      return /*#__PURE__*/_react().default.createElement("div", {
        className: (0, _classnames().default)(controlClass),
        onClick: onClickInput
      }, props.children);
    }

    var handleChange = function handleChange(e) {
      var _e$currentTarget;

      var maxlength = props.maxlength,
          onChange = props.onChange;
      var inputValue = e === null || e === void 0 ? void 0 : (_e$currentTarget = e.currentTarget) === null || _e$currentTarget === void 0 ? void 0 : _e$currentTarget.value;
      var finalValue = inputValue;

      if ((0, _utils.isDef)(maxlength) && finalValue.length > +maxlength) {
        finalValue = finalValue.slice(0, maxlength);
      }

      if (type === 'number' || type === 'digit') {
        var isNumber = type === 'number';
        finalValue = (0, _utils.formatNumber)(finalValue, isNumber, isNumber);
      }

      finalValue = formatValue(finalValue, 'onChange'); // if (inputRef.value && inputValue !== inputRef.value.value) {
      //   inputRef.value.value = inputValue;
      // }

      if (onChange && typeof onChange === 'function') {
        onChange(finalValue);
      }
    };

    var handleFocus = function handleFocus(e) {
      var onFocus = props.onFocus;
      setInputFocus(true);

      if (onFocus && typeof onFocus === 'function') {
        onFocus(e);
      } // readonly not work in legacy mobile safari


      if (readonly) {
        blur();
      }
    };

    var handleBulr = function handleBulr(e) {
      var onBlur = props.onBlur;
      setInputFocus(false);

      if (onBlur && typeof onBlur === 'function') {
        onBlur(e);
      }

      (0, _utils.resetScroll)();
    };

    var handleKeypress = function handleKeypress(e) {
      var onKeypress = props.onKeypress;

      if (e.key === 'Enter' || +e.charCode === 13) {
        if (props.type !== 'textarea') {
          (0, _utils.preventDefault)(e);
        } // trigger blur after click keyboard search button


        if (props.type === 'search') {
          blur();
        }
      }

      if (onKeypress && typeof onKeypress === 'function') {
        onKeypress(e);
      }
    };

    if (type === 'textarea') {
      return /*#__PURE__*/_react().default.createElement("textarea", {
        ref: inputRef,
        name: name,
        rows: rows,
        className: (0, _classnames().default)(controlClass),
        value: value,
        disabled: disabled,
        readOnly: readonly,
        placeholder: placeholder || '',
        onBlur: handleBulr,
        onFocus: handleFocus,
        onClick: onClickInput,
        onChange: handleChange,
        onKeyPress: handleKeypress
      });
    }

    var inputType = type;
    var inputMode; // type="number" is weired in iOS, and can't prevent dot in Android
    // so use inputmode to set keyboard in mordern browers

    if (type === 'number') {
      inputType = 'text';
      inputMode = 'decimal';
    }

    if (type === 'digit') {
      inputType = 'tel';
      inputMode = 'numeric';
    }

    return /*#__PURE__*/_react().default.createElement("input", {
      value: value,
      type: inputType,
      inputMode: inputMode,
      ref: inputRef,
      name: name,
      className: (0, _classnames().default)(controlClass),
      disabled: disabled,
      readOnly: readonly,
      placeholder: placeholder || '',
      onBlur: handleBulr,
      onFocus: handleFocus,
      onClick: onClickInput,
      onChange: handleChange,
      onKeyPress: handleKeypress
    });
  };

  var renderLeftIcon = function renderLeftIcon() {
    var leftIcon = props.leftIcon,
        onClickLeftIcon = props.onClickLeftIcon;
    if (!leftIcon) return null;
    return /*#__PURE__*/_react().default.createElement("div", {
      className: (0, _classnames().default)(bem('left-icon')),
      onClick: onClickLeftIcon
    }, typeof leftIcon !== 'string' ? leftIcon : /*#__PURE__*/_react().default.createElement(_icon.default, {
      name: leftIcon,
      classPrefix: props.iconPrefix
    }));
  };

  var renderRightIcon = function renderRightIcon() {
    var rightIcon = props.rightIcon,
        iconPrefix = props.iconPrefix,
        onClickRightIcon = props.onClickRightIcon;
    if (!rightIcon) return null;
    return /*#__PURE__*/_react().default.createElement("div", {
      className: (0, _classnames().default)(bem('right-icon')),
      onClick: onClickRightIcon
    }, typeof rightIcon === 'string' ? /*#__PURE__*/_react().default.createElement(_icon.default, {
      name: rightIcon,
      classPrefix: iconPrefix
    }) : rightIcon);
  };

  var renderWordLimit = function renderWordLimit() {
    var value = props.value,
        showWordLimit = props.showWordLimit,
        maxlength = props.maxlength;

    if (showWordLimit && maxlength) {
      var count = (value ? "".concat(value) : '').length;
      return /*#__PURE__*/_react().default.createElement("div", {
        className: (0, _classnames().default)(bem('word-limit'))
      }, /*#__PURE__*/_react().default.createElement("span", {
        className: (0, _classnames().default)(bem('word-num'))
      }, count), "/", maxlength);
    }

    return null;
  };

  var renderMessage = function renderMessage() {
    // if (form && form.props.showErrorMessage === false) {
    //   return null;
    // }
    var message = props.errorMessage;

    if (message) {
      var errorMessageAlign = getProp('errorMessageAlign');
      return /*#__PURE__*/_react().default.createElement("div", {
        className: (0, _classnames().default)(bem('error-message', errorMessageAlign))
      }, message);
    }

    return null;
  };

  var handleClear = function handleClear(e) {
    var onClear = props.onClear,
        onChange = props.onChange;
    inputRef.current.value = '';

    if (onChange && typeof onChange === 'function') {
      onChange('');
    }

    if (onClear && typeof onClear === 'function') {
      onClear(e);
    }
  };

  var type = props.type,
      label = props.label,
      size = props.size,
      center = props.center,
      border = props.border,
      isLink = props.isLink,
      required = props.required,
      clickable = props.clickable,
      labelAlign = props.labelAlign,
      className = props.className,
      labelClass = props.labelClass,
      arrowDirection = props.arrowDirection,
      autosize = props.autosize,
      disabled = props.disabled,
      button = props.button,
      error = props.error;
  return /*#__PURE__*/_react().default.createElement(_cell.default, {
    title: label || null,
    size: size,
    icon: renderLeftIcon(),
    center: center,
    border: border,
    isLink: isLink,
    required: required,
    clickable: clickable,
    extra: props.extra,
    titleStyle: labelStyle(),
    valueClass: (0, _classnames().default)(bem('value')),
    titleClass: (0, _classnames().default)(bem('label', labelAlign), labelClass),
    arrowDirection: arrowDirection,
    onClick: props === null || props === void 0 ? void 0 : props.onClick,
    className: (0, _classnames().default)(bem((_bem = {
      error: error,
      disabled: disabled
    }, (0, _defineProperty2().default)(_bem, "label-".concat(labelAlign), labelAlign), (0, _defineProperty2().default)(_bem, 'min-height', type === 'textarea' && !autosize), _bem)), className)
  }, /*#__PURE__*/_react().default.createElement("div", {
    className: (0, _classnames().default)(bem('body'))
  }, renderInput(), showClear && (typeof props.clearIcon === 'string' ? /*#__PURE__*/_react().default.createElement(_icon.default, {
    className: (0, _classnames().default)(bem('clear')),
    onTouchStart: handleClear,
    name: props.clearIcon,
    size: ICON_SIZE
  }) : props.clearIcon), renderRightIcon(), button && /*#__PURE__*/_react().default.createElement("div", {
    className: (0, _classnames().default)(bem('button'))
  }, button)), renderWordLimit(), renderMessage());
});
Field.defaultProps = {
  clearIcon: 'clear',
  clearTrigger: 'focus',
  formatTrigger: 'onChange'
};
var _default = Field;
exports.default = _default;