"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBEM = createBEM;

/* eslint-disable @typescript-eslint/no-explicit-any */

/* eslint-disable no-param-reassign */

/**
 * bem helper
 * b() // 'button'
 * b('text') // 'button__text'
 * b({ disabled }) // 'button button--disabled'
 * b('text', { disabled }) // 'button__text button__text--disabled'
 * b(['disabled', 'primary']) // 'button button--disabled button--primary'
 */
function gen(name, mods) {
  if (!mods) {
    return '';
  }

  if (typeof mods === 'string') {
    return " ".concat(name, "--").concat(mods);
  }

  if (Array.isArray(mods)) {
    return mods.reduce(function (ret, item) {
      return ret + gen(name, item);
    }, '');
  }

  return Object.keys(mods).reduce(function (ret, key) {
    return ret + (mods[key] ? gen(name, key) : '');
  }, '');
}

function createBEM(name) {
  return function (el, mods) {
    if (el && typeof el !== 'string') {
      mods = el;
      el = '';
    }

    el = el ? "".concat(name, "__").concat(el) : name;
    return "".concat(el).concat(gen(el, mods));
  };
}